<template>
  <a-card :bordered="false" :class="'cust-erp-sub-tab'">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- <div class="table-operator">
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增班组</a-button>
    </div> -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>
      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        @change="handleTableChange">
        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot="imgSlot" slot-scope="text,record">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt="" style="max-width:80px;font-size: 12px;font-style: italic;"/>
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)">
            下载
          </a-button>
        </template>

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>
          <a-divider type="vertical" />
          <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
            <a>删除</a>
          </a-popconfirm>
        </span>
      </a-table>
    </div>
    <team-modal ref='modalForm' @ok='modalFormOk' :mainId="mainId"></team-modal>
  </a-card>
</template>
<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import TeamModal from './TeamModal.vue'
  export default {
    name: "TeamList",
    mixins:[JeecgListMixin],
    components: {TeamModal },
    props:{
      mainId:{
        type:String,
        default:'',
        required:false
      }
    },
    watch:{
      mainId:{
        immediate: true,
        handler(val) {
          if(!this.mainId){
            this.clearList()
          }else if(val!=='-1'){
            this.queryParam['departId'] = val
            this.queryParam['delFlag'] = '0'
            this.loadData(1);
          }else{
            this.queryParam['delFlag'] = '0'
            this.loadData(1);
          }
        }
      }
    },
    data () {
      return {
        description: '材料出库单管理页面',
        disableMixinCreated:true,
        // 表头
        columns: [
          {
            title: '#',
            dataIndex: '',
            key:'rowIndex',
            width:60,
            align:"center",
            customRender:function (t,r,index) {
              return parseInt(index)+1;
            }
          },
          {
            title:'班组编码',
            align:"center",
            dataIndex: 'num',
            width:100
          },
          {
            title:'班组名称',
            align:"center",
            dataIndex: 'name',
            width:100
          },
          {
            title:'创建人',
            align:"center",
            dataIndex: 'createBy',
            width:100,
          },
          {
            title:'创建日期',
            align:"center",
            dataIndex: 'createTime',
            width:100,
          },
          {
            title:'更新人',
            align:"center",
            dataIndex: 'updateBy',
            width:100,
          },
          {
            title:'更新日期',
            align:"center",
            dataIndex: 'updateTime',
            width:100,
          },
        ],
        url: {
          list: "/base/team/list",
        },
        dictOptions:{
        }
      }
    },
    created() {
    },
    computed: {
      importExcelUrl(){
        return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`;
      }
    },
    methods: {
      clearList(){
        this.dataSource=[]
        this.selectedRowKeys=[]
        this.ipagination.current = 1
      },
      handleAdd(){
       this.$refs.modalForm.title = "新增"
       this.$refs.modalForm.visible = true;
      }
    },
  
  }
</script>
<style scoped>
  @import '~@assets/less/common.less'
</style>
